#!/bin/bash
install_and_display_result(){
  echo "Installing $1."
  rpm -i $1
  if [ $? -eq 0 ]
  then
    echo "$1 installed successfully."
  else
    echo "$1 installation failed."
  fi
}

# Initialize variables
os_name=""
release_file=""
os_version=""

# Determine OS flavor from /etc/os-release
os_name=$(grep -oP '^ID=\K.*' /etc/os-release | tr -d '"')

# Set the release file path based on the OS name
case "$os_name" in
    rhel)
        release_file="/etc/redhat-release"
        ;;
    centos)
        release_file="/etc/centos-release"
        ;;
    rocky)
        release_file="/etc/rocky-release"
        ;;
    *)
        echo "Warning: Unsupported operating system. This package only supports RHEL, CentOS, or Rocky."
        ;;
esac

# Retrieve the full version number
if [ -f "$release_file" ]; then
    os_version=$(grep -oP '(\d+\.\d+)' "$release_file")

    # Correct version comparison using IFS splitting
    IFS='.' read -r major minor <<< "$os_version"
    IFS='.' read -r req_major req_minor <<< 8.2

    # Check if the OS version is less than 8.2
    if (( major < req_major || (major == req_major && minor < req_minor) )); then
        echo "Current OS version is $os_version"
        echo "Error: This package requires $os_name version 8.2 or higher."
        exit 1
    fi
fi

install_and_display_result "adskidentitymanager1.12.0.7-1.x86_64.rpm"
install_and_display_result "adskflexnetclient-11.18.3-1.x86_64.rpm"
install_and_display_result "adlmapps31-31.0.4-0.x86_64.rpm"
install_and_display_result "adsklicensing15.2.0.12803-0-0.x86_64.rpm"
